===================
介绍
===================
1. 作为一个经常使用transformers包的工程师
2. 作为一个不能远程、懒得远程的，但是有时候需要了解transformers训练的情况的工程师
3. 我发布了这个包，用来解决远程无法查看模型训练效果的问题。


使用起来很简单，建议直接查看GitHub上的介绍：`<https://github.com/yuanzhoulvpi2017/nlpboss>`_
